@@ -1,8 +1,11 @@
 #!/usr/local/bin/wish -f
 
-# $Header: /cluster21/kennykb/src/tclTCP/RCS/bars.tcl,v 1.1 1992/02/14 20:02:23 kennykb Exp kennykb $
-# $Source: /cluster21/kennykb/src/tclTCP/RCS/bars.tcl,v $
+# $Header: /net/src/prog-tools/btcl.alpha/tclTCP2.2/demos/RCS/bars.tcl,v 1.1 1996/01/26 15:29:46 vanandel Exp $
+# $Source: /net/src/prog-tools/btcl.alpha/tclTCP2.2/demos/RCS/bars.tcl,v $
 # $Log: bars.tcl,v $
+# Revision 1.1  1996/01/26  15:29:46  vanandel
+# Initial revision
+#
 # Revision 1.1  1992/02/14  20:02:23  kennykb
 # Initial revision
 #
@@ -38,6 +41,10 @@ puts stderr "bars: serving on port $p"
 
 set c [tcp connect localhost 2324]
 
+# Get a name for this application in the master server
+
+set myname [$c send gensym bars]
+
 # Make a procedure to send colors, unless the master server just sent them to
 # us.
 
@@ -78,9 +85,9 @@ button .quit -text "Quit" -command "destroy ."
 pack append . .text {top expand fillx} \
 	.bars {top expand fill} \
 	.quit {top expand fillx}
-puts stderr "packing complete"
+#puts stderr "packing complete"
 update
-puts stderr "update complete"
+#puts stderr "update complete"
 
 # Define a local procedure to receive a new set of colors and update the
 # display
@@ -91,9 +98,6 @@ proc newcolors {red green blue} {
 	.bars.blue set $blue
 }
 
-# Get a name for this application in the master server
-
-set myname [$c send gensym bars]
 
 # Define a procedure in the master server to update our colors
 
@@ -141,17 +145,17 @@ proc startTracing {} {
 
 # Make the master server open a connection to us, and start tracing.
 
-set action [format {
+set action [format { after 1000 {
 		set %s.connection [tcp connect localhost %d]
-		puts stderr "got connection to bar"
+#		puts stderr "got connection to bar"
 		%s.update
-		puts stderr "before send of startTracing"
+#		puts stderr "before send of startTracing"
 		${%s.connection} send after 1000 startTracing
-		puts stderr "after send of startTracing"
+#		puts stderr "after send of startTracing" }
 	} $myname $p \
 	  $myname \
 	  $myname \
 	  $myname]
-$c send after 1000 $action
+$c send $action
 
 
