@@ -1,8 +1,14 @@
 #!/usr/local/bin/wish -f
 
-# $Header: /cluster21/kennykb/src/tclTCP/RCS/entries.tcl,v 1.1 1992/02/14 20:02:54 kennykb Exp kennykb $
-# $Source: /cluster21/kennykb/src/tclTCP/RCS/entries.tcl,v $
+# $Header: /net/src/prog-tools/btcl.alpha/tclTCP2.2/demos/RCS/entries.tcl,v 1.2 1996/01/26 15:29:46 vanandel Exp $
+# $Source: /net/src/prog-tools/btcl.alpha/tclTCP2.2/demos/RCS/entries.tcl,v $
 # $Log: entries.tcl,v $
+# Revision 1.2  1996/01/26  15:29:46  vanandel
+# *** empty log message ***
+#
+# Revision 1.1  1996/01/26  01:48:11  vanandel
+# Initial revision
+#
 # Revision 1.1  1992/02/14  20:02:54  kennykb
 # Initial revision
 #
@@ -30,7 +36,7 @@
 # Do keyboard and mouse bindings for an entry box.
 
 proc bindentry {w {command eval}} {
-	bind $w <Any-KeyPress> {%W insert insert "%A"; entry.cursor %W}
+	bind $w <Any-KeyPress> {%W insert insert "%A"; entry.cursor %W; break}
 	bind $w <space> {%W insert insert " "; entry.cursor %W}
 	bind $w <Control-a> {%W icursor 0; %W view 0}
 	bind $w <Control-b> {entry.cursorleft %W}
@@ -108,7 +114,7 @@ proc entry.deleteright {w} {
 
 proc entry.center {win} {
 	set cursor_position [$win index insert]
-	$win view 0
+	$win xview 0
 	set left_extent [$win index @0]
 	set right_extent [$win index @[winfo width $win]]
 	set entry_length [expr {$right_extent - $left_extent}]
@@ -260,13 +266,15 @@ proc startTracing {} {
 # Make the master server open a connection to us, and start tracing.
 
 set action [format {
+    	    	after 10 {
 		set %s.connection [tcp connect localhost %d]
 		%s.update
-		${%s.connection} send after 10 startTracing
+		${%s.connection} send after 10 startTracing}
 	} $myname $p \
 	  $myname \
 	  $myname \
 	  $myname]
-$c send after 10 $action
+$c send $action
+#tcp mainloop
 
 
