@@ -7,18 +7,24 @@
     
 #if !defined(lint) && !defined(VX)
 static char rcsid[]=
-"$Header: /net/thor/rsg/radar/src/lib/streamsock/RCS/readFullBuf.c,v 1.2 90/02/12 14:29:18 vanandel Exp $";
+"$Header: /net/src3/btcl/tclTCP2.1/src/RCS/readFullBuf.c,v 1.2 1994/08/04 13:27:31 vanandel Exp $";
 #endif
 
 /******************************************************************************
 * Revision history:
-* $Log:	readFullBuf.c,v $
+* $Log: readFullBuf.c,v $
+ * Revision 1.2  1994/08/04  13:27:31  vanandel
+ * *** empty log message ***
+ *
+ * Revision 1.1  1994/03/09  18:46:39  vanandel
+ * Initial revision
+ *
  * Revision 1.2  90/02/12  14:29:18  vanandel
  * added RCS header
  * 
 * 
 *********************************END OF RCS INFO******************************/
-
+#include <unistd.h>
 
 /*
  * since we aren't guarenteed to get all the data requested when we
