@@ -8,8 +8,8 @@
  */
 
 char RCSid_simpleEvent [] =
-  "$Header: /net/src3/btcl/tclTCP2.1/src/RCS/simpleEvent.c,v 1.2 1994/08/04 13:31:26 vanandel Exp $";
-/* $Source: /net/src3/btcl/tclTCP2.1/src/RCS/simpleEvent.c,v $
+  "$Header: /net/src/prog-tools/btcl.alpha/tclTCP2.2/src/RCS/simpleEvent.c,v 1.2 1994/08/04 13:31:26 vanandel Exp vanandel $";
+/* $Source: /net/src/prog-tools/btcl.alpha/tclTCP2.2/src/RCS/simpleEvent.c,v $
  * $Log: simpleEvent.c,v $
  * Revision 1.2  1994/08/04  13:31:26  vanandel
  * change to allow sharing source with VxWorks version
@@ -38,7 +38,11 @@ char RCSid_simpleEvent [] =
 
 #include <errno.h>
 #include <tclInt.h>
+#ifdef NOTDEF
 #include <tclUnix.h>
+#else
+#include <tclPort.h>
+#endif
 
 #ifdef TCL_VW
 #include <vxWorks.h>
