@@ -8,17 +8,25 @@
  * display.
  */
 
+/* #define DEBUG2 */
 #define STATIC
 
-#ifndef ERROR
-#define ERROR -1
-#endif
 
 
 static char RCSid [] =
-  "$Header: /net/src3/tcl7/tclTCP1.1/RCS/tclTCP.c,v 1.5 1993/11/22 18:31:54 vanandel Exp vanandel $";
-/* $Source: /net/src3/tcl7/tclTCP1.1/RCS/tclTCP.c,v $
+  "$Header: /net/src3/btcl/tclTCP2.1/src/RCS/tclTCP.c,v 1.8 1994/08/04 13:33:09 vanandel Exp vanandel $";
+/* $Source: /net/src3/btcl/tclTCP2.1/src/RCS/tclTCP.c,v $
  * $Log: tclTCP.c,v $
+ * Revision 1.8  1994/08/04  13:33:09  vanandel
+ * change to have common version with vxworks port of TCL
+ *
+ * Revision 1.7  1994/07/12  21:01:03  vanandel
+ * plug 2 core leaks, fix setsockopt() call arguments
+ *
+ * Revision 1.6  1994/05/11  15:57:42  vanandel
+ * change from merge to Tcl_Concat to handle remote arguments better
+ *
+ *
  * Revision 1.5  1993/11/22  18:31:54  vanandel
  * added more debug statements, don't send \n at end of command lines
  * anymore
@@ -103,9 +111,12 @@ static char copyright [] =
 #include <hostLib.h>
 
 #include "tcl.h"
+
+#define TASK(t) Tcl_ctxt->t
 #else
+#define TASK(t) t
 
-
+#include <unistd.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <sys/socket.h>
@@ -113,9 +124,16 @@ static char copyright [] =
 #include <netdb.h>
 #include <arpa/inet.h>
 #include <signal.h>
+#ifndef FIONBIO
+#include <sys/filio.h>	/* for FIONBIO */
+#endif
 
 #endif
 
+#ifndef ERROR
+#define ERROR -1
+#endif
+
 /* Only some copies of netinet/in.h have the following defined. */
 
 #ifndef INADDR_LOOPBACK
@@ -128,7 +146,7 @@ static char copyright [] =
 
 
 #include <tclInt.h>
-#include <tclUnix.h>
+#include <tclPort.h>
 #include "tclTCP.h"
 #include "simpleEvent.h"
 
@@ -144,20 +162,16 @@ static char copyright [] =
  * certainly not a portable one.
  */
 
-extern int accept _ANSI_ARGS_((int, struct sockaddr *, int *));
-extern int bind _ANSI_ARGS_((int, const struct sockaddr *, int));
 extern int close _ANSI_ARGS_((int));
-extern int connect _ANSI_ARGS_((int, const struct sockaddr *, int));
+#ifdef NOTDEF
 extern int gethostname _ANSI_ARGS_((char *, int));
 extern int getsockname _ANSI_ARGS_((int, struct sockaddr *, int *));
-#ifdef NOTDEF
-extern int ioctl _ANSI_ARGS_((int, int, char *));
-extern int read _ANSI_ARGS_((int, char *, int));
-#endif
 extern int listen _ANSI_ARGS_((int, int));
 extern int select _ANSI_ARGS_((int, fd_set *, fd_set *, fd_set *,
 			       struct timeval *));
 extern int socket _ANSI_ARGS_((int, int, int));
+extern int ioctl _ANSI_ARGS_((int, int, char *));
+#endif
 
 
 /* Configuration parameters */
@@ -362,6 +376,12 @@ tcpClientObjectServerCmd _ANSI_ARGS_((ClientData clientData,
 				      Tcl_Interp * interp,
 				      int argc, char * * argv));
 
+/* Users command added by Dale Larson to support rlogin-style connections */
+STATIC int
+tcpUsersCommand _ANSI_ARGS_((ClientData clientData,
+				       Tcl_Interp * interp,
+				       int argc, char * * argv));
+
 STATIC void
 deleteTcpClientObjectCmd _ANSI_ARGS_((ClientData clientData));
 
@@ -450,6 +470,11 @@ tcpReceiveResultFromServer _ANSI_ARGS_((Tcl_Interp * interp, int s));
  *		Wait for a server to have work to do.
  *----------------------------------------------------------------------
  */
+/* The next two declarations added by Dale Larson to support rlogin-style
+ * connections...set tcpUsersCommand and tcpTrustedHost
+ */
+char ruser[80] = {""};		/* Remote user name */
+char luser[80] = {""};		/* Local user name  */
 
 int
 tcpCommand (clientData, interp, argc, argv)
@@ -461,6 +486,13 @@ tcpCommand (clientData, interp, argc, argv)
   char c;
   unsigned length;
 
+#ifdef nOTDEF
+  if (Tcl_ctxt == NULL)
+  {
+    logMsg("bad Tcl_ctxt");
+    taskSuspend(0);
+  }
+#endif
 
   if (argc < 2) {
     Tcl_AppendResult (interp, "wrong # args: should be \"", argv [0],
@@ -498,12 +530,16 @@ tcpCommand (clientData, interp, argc, argv)
   if ((c == 's') && (strncmp (argv [1], "server", length) == 0)) {
     return tcpServerCommand (clientData, interp, argc-1, argv+1);
   }
+/* Users command added by Dale Larson to support rlogin-style TrustedHost */
+  if ((c == 'u') && (strncmp (argv [1], "users", length) == 0)) {
+    return tcpUsersCommand (clientData, interp, argc-1, argv+1);
+  }
   if ((c == 'w') && (strncmp (argv [1], "wait", length) == 0)) {
     return tcpWaitCommand (clientData, interp, argc-1, argv+1);
   }
   Tcl_AppendResult (interp, "bad option \"", argv [1],
-		    "\": should be client, eval, login,",
-		    " mainloop, poll, servers, server or wait",
+		    "\": should be \nclient, eval, login,",
+		    " mainloop, poll, servers, server, users, or wait",
 		    (char *) NULL);
   return TCL_ERROR;
 
@@ -535,12 +571,12 @@ tcpClientCommand (clientData, interp, argc, argv)
 
   /* Make sure there is a current client */
 
-  if (tcpCurrentClient == NULL) {
+  if (TASK(tcpCurrentClient) == NULL) {
     Tcl_SetResult (interp, "no current client", TCL_STATIC);
     return TCL_ERROR;
   }
 
-  Tcl_SetResult (interp, tcpCurrentClient, TCL_VOLATILE);
+  Tcl_SetResult (interp, TASK(tcpCurrentClient), TCL_VOLATILE);
   return TCL_OK;
 }
 
@@ -753,6 +789,7 @@ tcpLoginCommand (clientData, interp, argc, argv)
 	Tcl_AppendResult (interp, "GE DICE TCP-based Tcl server\n", RCSid,
 			  "\n", copyright, (char *) NULL);
 
+	ckfree ((char *) hostName);
 	return TCL_OK;
 
       }
@@ -798,7 +835,7 @@ tcpMainLoopCommand (clientData, interp, argc, argv)
 
   do {
     status = simpleSelect (SIMPLE_WAIT | SIMPLE_DO_EVENTS);
-  } while (status >= 0);
+  } while ( status >= 0 );
 
   /* In a non-Tk environment, errno has a Unix error or 0 for no clients
    * or servers.  In a Tk environment, errno is zero at this point.
@@ -947,13 +984,13 @@ tcpServerCommand (clientData, interp, argc, argv)
 
 	  /* Link the server on the list of active servers */
 
-	  if (tcpFirstServer)
+	  if (TASK(tcpFirstServer))
 	  {
-	    tcpFirstServer -> prev = server;
+	    TASK(tcpFirstServer) -> prev = server;
 	  }
 
-	  server -> next = tcpFirstServer;
-	  tcpFirstServer = server;
+	  server -> next = TASK(tcpFirstServer);
+	  TASK(tcpFirstServer) = server;
 	  server -> prev = NULL;
 
 	  /* Add the server object command */
@@ -1020,13 +1057,48 @@ tcpServersCommand (clientData, interp, argc, argv)
     return TCL_ERROR;
   }
 
-  for (server = tcpFirstServer; server != NULL; server = server -> next) {
+  for (server = TASK(tcpFirstServer); server != NULL; server = server -> next) {
     Tcl_AppendElement (interp, server -> name);
   }
 
   return TCL_OK;
 }
 
+/* tcpUsersCommand:
+ *
+ *	This procedure is invoked to process the "tcp users" Tcl
+ * command.  It sets the ruser and luser variables used by tclTrustedHost
+ * in the call to ruserok to validate a connection.  This code was added
+ * by Dale Larson.
+ *
+ * Syntax:
+ *	tcp users ?-ruser string? and ?-luser string?
+ * 
+ * Results:
+ *	A standard Tcl result.  Return value is "ruser luser".
+ */
+
+/* ARGSUSED */
+STATIC int
+tcpUsersCommand (clientData, interp, argc, argv)
+     ClientData clientData;
+     Tcl_Interp * interp;
+     int argc;
+     char * * argv;
+{
+  /* Check command syntax */
+  if (argc != 3 ) {
+    Tcl_AppendResult (interp, "wrong # args; should be \"", argv [-1], " ",
+		      argv [0], " remoteUserName localUserName\"", (char *) NULL);
+    return TCL_ERROR;
+  }
+  strcpy (ruser,argv[1]);
+  strcpy (luser,argv[2]);
+  Tcl_SetResult (interp, ruser, TCL_VOLATILE );
+  Tcl_AppendResult (interp, " ",luser, (char *) NULL);
+  return TCL_OK;
+}
+
 /*
  * tcpWaitCommand:
  *
@@ -1513,7 +1585,7 @@ deleteTcpServerObjectCmd (clientData)
   if (server -> prev != NULL)
     server -> prev -> next = server -> next;
   else
-    tcpFirstServer = server -> next;
+    TASK(tcpFirstServer) = server -> next;
 
   /* If all clients are closed, get to tcpDeleteServer now.  Otherwise, set
    * the server's stop flag and return.
@@ -1661,8 +1733,8 @@ tcpServerObjectConfig (clientData, interp, argc, argv)
 
 	/* re-use the port number (if not still in use) */
 
-	if (setsockopt(server->socketfd,SOL_SOCKET,SO_REUSEADDR,&one,
-		sizeof one) == ERROR) 
+	if (setsockopt(server->socketfd,SOL_SOCKET,SO_REUSEADDR,(char *)&one,
+		(int) sizeof one) == ERROR) 
 	{
 		(void) close(server->socketfd);
 		return(ERROR);
@@ -1889,8 +1961,8 @@ tcpClientObjectDoCmd (clientData, interp, argc, argv)
     return TCL_ERROR;
   }
 
-  prevClient = tcpCurrentClient;
-  tcpCurrentClient = client -> name;
+  prevClient = TASK(tcpCurrentClient);
+  TASK(tcpCurrentClient) = client -> name;
 
   /* Evaluate the client's command, passing the client name and message */
 
@@ -1908,7 +1980,11 @@ tcpClientObjectDoCmd (clientData, interp, argc, argv)
 
   /*DEBUG*/
 #ifdef DEBUG2
-  fprintf(stderr, "tcpClientObjectDoCmd evaluating %s\n", excmd);
+  if(excmd)
+      fprintf(stderr, "tcpClientObjectDoCmd evaluating %s\n", excmd);
+  else
+      fprintf(stderr, "tcpClientObjectDoCmd evaluating 'do'\n");
+
 #endif
 
   status = Tcl_VarEval (interp, client -> command, " ", client -> name, " ",
@@ -1922,7 +1998,7 @@ tcpClientObjectDoCmd (clientData, interp, argc, argv)
   }
 
   client -> activeFlag = 0;
-  tcpCurrentClient = prevClient;
+  TASK(tcpCurrentClient) = prevClient;
 
   /* If the client command throws an error on login or logout,
    * the client should be disconnected.
@@ -2185,12 +2261,18 @@ tcpConnectionObjectSendCmd (clientData, interp, argc, argv)
 
   /* Paste together the message */
 
-  message = Tcl_Merge (argc-1, argv+1);
-
+  if (argc > 2) {
+      message = Tcl_Concat (argc-1, argv+1);
+  } else {
+      message = argv[1];
+  }
   /* Send the command to the server */
 
   status = tcpSendCmdToServer (interp, f, message);
-  ckfree(message);
+
+  if (message != argv[1]) {
+      ckfree(message);
+  }
   if (status != TCL_OK)
     return status;
 
@@ -2280,6 +2362,7 @@ tcpServerAcceptConnection (clientData, mask)
     fprintf(stderr, "tcpServerAcceptConnetion: eval %s do\n", clientName);
 #endif
     status = Tcl_VarEval (server -> interp, clientName, " do", (char *) NULL);
+    ckfree(clientName);
 
     /* Client may have been closed at this point.  Don't refer to it again. */
   }
@@ -2397,8 +2480,11 @@ tcpTrustedHost (hostName)
       }
     }
   }
+/* If not localhost, then try authenticating user/host with ruserok
+ * code added by Dale Larson to support remote connections
+ */
+  return ruserok (hostName,0,ruser,luser) == 0 ? 1 : 0;
 
-  return 0;
 #endif
 }
 
@@ -2595,7 +2681,8 @@ tcpReceiveClientInput (clientData, mask)
      fprintf(stderr, "received %s from client\n", command);
 #endif
 
-  if (Tcl_CommandComplete(command)){
+/* don't evaluate a single \n character - we'll confuse our caller */
+  if (strcmp(command,"\n") && Tcl_CommandComplete(command)){
 #ifdef DEBUG2
     fprintf(stderr, "DEBUG: processing (%s)\n", command);
 #endif
@@ -2708,7 +2795,6 @@ tcpSendCmdToServer (interp, s, message)
   int length;
   int unixStatus;
   int rubbish;
-  static char newline = '\n';
   void (*oldPipeHandler) ();
 
   /* Set the socket for blocking I/O */
@@ -2742,24 +2828,6 @@ tcpSendCmdToServer (interp, s, message)
     return TCL_ERROR;
   }
 
-#ifdef NOTDEF
-  /* Write the terminating newline */
-
-  unixStatus = write (s, &newline, 1);
-  if (unixStatus < 1) {
-#ifndef TCL_VW
-    (void) signal (SIGPIPE, oldPipeHandler);
-#endif
-    Tcl_AppendResult (interp, "can't send newline to server: ",
-		      Tcl_PosixError (interp), (char *) NULL);
-    return TCL_ERROR;
-  }
-
-
-#ifndef TCL_VW
-  (void) signal (SIGPIPE, oldPipeHandler);
-#endif
-#endif
   return TCL_OK;
 }
 
@@ -2785,7 +2853,7 @@ tcpReceiveResultFromServer (interp, s)
   struct timeval * tickp;
   fd_set readfds;
   char buf [BUFSIZ+1];
-  char * reply;
+  char * reply = NULL;
   int rargc;
   char * * rargv;
   int rstatus;
@@ -2884,7 +2952,7 @@ tcpReceiveResultFromServer (interp, s)
   if (status == TCL_OK) {
     if (rargc != 2) {
       Tcl_SetResult (interp, "server returned malformed list", TCL_STATIC);
-#ifdef DEBUG2
+#ifdef DEBUG1
       fprintf(stderr, "DEBUG: malformed list {%s}\n", reply);
 #endif
       status = TCL_ERROR;
